CircularBuffer<T> class

Constructors

CircularBuffer({required int maxSize})

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isNotEmpty bool
no setter
last → T?
no setter
length int
no setter
maxSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(T item) → void
clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() List<T>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited